@@ -16,14 +16,20 @@
 from .env import webui, webui_host, webui_port
 
 
-def get_app(commands_processor, api_url, anonymous=False):
+def get_app(call, api_url, anonymous=False):
     from . import client
-    client.commands_processor = commands_processor
-    client.anonymous = anonymous
-    client.api_url = api_url
-    from . import cursors
-    # XXX
-    if anonymous:
-        cursors.home_mount = cursors.network_mount
+    from .client import Client
     from .app import app
+    from . import cursors
+
+    client._call = call
+    Client.api_url = api_url
+    Client.anonymous = anonymous
+
+    if anonymous:
+        Client.sugar_uid = 'demo'
+        cursors.home_mount = cursors.network_mount
+    else:
+        Client.sugar_uid = Client.call('GET', [], cmd='whoami')['guid']
+
     return app
