@@ -34,8 +34,7 @@ from werkzeug import secure_filename
 import simplejson
 import tempfile
 
-from sugar_network import client
-from sugar_network.toolkit.http import NotFound 
+from sugar_network.toolkit.http import NotFound
 from client import Client
 
 _BUFFER_SIZE = 1024 * 10
@@ -52,6 +51,8 @@ app.config['BABEL_DEFAULT_LOCALE'] = 'en'
 app.config['BABEL_DEFAULT_TIMEZONE'] = 'America/Lima'
 app.config['UPLOAD_FOLDER'] = UPLOAD_FOLDER
 
+from feeds import *
+
 from cursors import *
 
 from dialogs import *
@@ -98,8 +99,7 @@ def timedelta(mtime):
 
 
 def get_colors():
-    from . import client
-    if client.anonymous:
+    if Client.anonymous:
         return ('#000000', '#000000')
 
     try:
@@ -114,7 +114,7 @@ def get_user():
     try:
         import gconf
     except ImportError:
-        return 'demo' 
+        return 'demo'
     conf = gconf.client_get_default()
     return conf.get_string('/desktop/sugar/user/nick')
 
@@ -148,7 +148,7 @@ def inject_vars():
     # Here we can inject variables into every template call
     stroke, fill = get_colors()
     kwvar = {
-        'userid': client.sugar_uid(),
+        'userid': Client.sugar_uid,
         'sugar_nick' : get_user()
         }
     return dict(stroke=stroke, fill=fill, **kwvar)
@@ -166,6 +166,7 @@ def before_request():
         g.Artifacts = home_mount.Artifacts
         g.Projects = home_mount.Projects
         g.autocomplete_Contexts = home_mount.autocomplete_Contexts
+        g.feed_Contexts = home_mount.feed_Contexts
         g.Questions = home_mount.Questions
         g.Ideas = home_mount.Ideas
         g.Problems = home_mount.Problems
@@ -173,6 +174,7 @@ def before_request():
         g.Comments = home_mount.Comments
         g.Reviews = home_mount.Reviews
         g.Resources = home_mount.Resources
+        g.feed_Resources = home_mount.feed_Resources
     else:
         g.client = network_mount.client
         g.Contexts = network_mount.Contexts
@@ -180,6 +182,7 @@ def before_request():
         g.Artifacts = network_mount.Artifacts
         g.Projects = network_mount.Projects
         g.autocomplete_Contexts = network_mount.autocomplete_Contexts
+        g.feed_Contexts = network_mount.feed_Contexts
         g.Questions = network_mount.Questions
         g.Ideas = network_mount.Ideas
         g.Problems = network_mount.Problems
@@ -187,15 +190,16 @@ def before_request():
         g.Comments = network_mount.Comments
         g.Reviews = network_mount.Reviews
         g.Resources = network_mount.Resources
+        g.feed_Resources = home_mount.feed_Resources
 
 
 def incoming(event):
     global _pull_events
     _pull_events.append(event)
     #if event['event']=='inline' and event.get('state')=='offline':
-    #    session['connected'] = False 
+    #    session['connected'] = False
     #if event['event']=='inline' and event.get('state')=='online':
-    #    session['connected'] = True 
+    #    session['connected'] = True
     return None
 _pull_listener = Client.connect(incoming)
 
@@ -221,7 +225,7 @@ def stars(context=None):
     guid = context[5:]  # remove "stars-" from id
     favorite = request.args.get('favorite')
 
-    Client.call('PUT', document='context', guid=guid, cmd='favorite',
+    Client.call('PUT', ['context', guid], 'favorite',
             content=(favorite == 'true'))
 
     # TODO Need to reset query object until supporting notifications
@@ -238,8 +242,7 @@ def moon(context=None):
     clone = request.args.get('clone', None)
     guid = context[5:]  # remove "moon-" from id
 
-    Client.call('PUT', document='context', guid=guid, cmd='clone',
-            content=1 if clone == 'true' else 0)
+    Client.call('PUT', ['context', guid], 'clone', clone == 'true', spawn=True)
 
     return jsonify(clone=clone)
 
@@ -293,7 +296,7 @@ def new_resource(context_guid=None):
         context = g.Contexts[offset]
     else:
         context = g.client.Context(context_guid,
-                                    reply=['title', 'favorite', 'clone'])
+                                    reply=['title', 'layer'])
     return render_template('resource-form.html', context=context)
 
 
@@ -334,7 +337,8 @@ def artifact_copy(guid):
     blob = artifact.get_blob('data')
     document_path = get_documents_path()
     with file(os.path.join(document_path, filename), 'w') as f:
-        f.write(blob.read())
+        for chunk in blob:
+            f.write(chunk)
     title = _('Artifact has been downloaded.')
     body = _('Success!\n\n'
              'File %(filename)s has been copied to your Documents folder.\n'
@@ -619,7 +623,7 @@ def project_browser(context_guid=None):
         template = 'context-view.html'
         context = g.client.Context(context_guid,
                     reply=['guid', 'title', 'description', 'author',
-                           'summary', 'favorite', 'clone', 'type'])
+                           'summary', 'layer', 'type'])
         try:
             session['last_context_title'] = context['title']
         except NotFound:
@@ -666,7 +670,7 @@ def reviews_browser(resource_guid=None, review_guid=None):
         template = 'context-view.html'
         context = g.client.Context(resource_guid,
                     reply=['guid', 'title', 'description', 'author',
-                    'summary', 'favorite', 'clone', 'type'])
+                    'summary', 'layer', 'type'])
         try:
             session['last_context_title'] = context['title']
         except NotFound:
@@ -712,7 +716,7 @@ def solution_browser(resource_guid=None):
         try:
             context = g.client.Context(resource['context'],
                     reply=['guid', 'title', 'description', 'summary', 'author',
-                           'favorite', 'clone', 'type'])
+                           'layer', 'type'])
         except:
             return redirect(url_for('resource_list'))
 
@@ -724,9 +728,9 @@ def solution_browser(resource_guid=None):
 
 @app.route('/context/view/<context_guid>/<query>')
 @app.route('/context/view/<context_guid>')
-@app.route('/context/questions/<context_guid>')
-@app.route('/context/ideas/<context_guid>')
-@app.route('/context/problems/<context_guid>')
+@app.route('/context/questions/<context_guid>', endpoint='context_question_browser')
+@app.route('/context/ideas/<context_guid>', endpoint='context_idea_browser')
+@app.route('/context/problems/<context_guid>', endpoint='context_problem_browser')
 @app.route('/context/artifacts/<context_guid>')
 @app.route('/context/gallery/<context_guid>')
 @app.route('/context/all/<context_guid>')
@@ -773,7 +777,7 @@ def context_resource_browser(context_guid=None, query=None):
         context = resource_cursor[offset]
     else:
         context = g.client.Context(context_guid, reply=['guid', 'title',
-            'author', 'summary', 'description', 'favorite', 'clone', 'type'])
+            'author', 'summary', 'description', 'layer', 'type'])
     try:
         session['last_context'] = context['guid']
         session['last_context_title'] = context['title']
